@@ -50,7 +50,7 @@ g_mime_data_wrapper_get_type (void)
 			NULL, /* class_finalize */
 			NULL, /* class_data */
 			sizeof (GMimeDataWrapper),
-			16,   /* n_preallocs */
+			0,    /* n_preallocs */
 			(GInstanceInitFunc) g_mime_data_wrapper_init,
 		};
 		
@@ -102,7 +102,7 @@ g_mime_data_wrapper_finalize (GObject *object)
 GMimeDataWrapper *
 g_mime_data_wrapper_new (void)
 {
-	return (GMimeDataWrapper *) g_object_new (GMIME_TYPE_DATA_WRAPPER, NULL, NULL);
+	return (GMimeDataWrapper *) g_object_new (GMIME_TYPE_DATA_WRAPPER, NULL);
 }
 
 
