@@ -1,8 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
- *
- *  Copyright 2003-2004 Ximian, Inc. (www.ximian.com)
+/*  GMime
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,8 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
- *
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -34,11 +31,11 @@
 
 /* text/enriched is rfc1896 */
 
-typedef char * (*EnrichedParamParser) (const char *inptr, int inlen);
+typedef char * (*EnrichedParamParser) (const char *inptr, size_t inlen);
 
-static char *param_parse_colour (const char *inptr, int inlen);
-static char *param_parse_font (const char *inptr, int inlen);
-static char *param_parse_lang (const char *inptr, int inlen);
+static char *param_parse_colour (const char *inptr, size_t inlen);
+static char *param_parse_font (const char *inptr, size_t inlen);
+static char *param_parse_lang (const char *inptr, size_t inlen);
 
 static struct {
 	char *enriched;
@@ -139,7 +136,7 @@ g_mime_filter_enriched_class_init (GMimeFilterEnrichedClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GMimeFilterClass *filter_class = GMIME_FILTER_CLASS (klass);
-	int i;
+	guint i;
 	
 	parent_class = g_type_class_ref (GMIME_TYPE_FILTER);
 	
@@ -187,7 +184,7 @@ enriched_tag_needs_param (const char *tag)
 	int i;
 	
 	for (i = 0; i < NUM_ENRICHED_TAGS; i++)
-		if (!strcasecmp (tag, enriched_tags[i].enriched))
+		if (!g_ascii_strcasecmp (tag, enriched_tags[i].enriched))
 			return enriched_tags[i].needs_param;
 	
 	return FALSE;
@@ -207,15 +204,14 @@ static const char *valid_colours[] = {
 #define NUM_VALID_COLOURS  (sizeof (valid_colours) / sizeof (valid_colours[0]))
 
 static char *
-param_parse_colour (const char *inptr, int inlen)
+param_parse_colour (const char *inptr, size_t inlen)
 {
 	const char *inend, *end;
 	guint32 rgb = 0;
-	guint v;
-	int i;
+	guint v, i;
 	
 	for (i = 0; i < NUM_VALID_COLOURS; i++) {
-		if (!strncasecmp (inptr, valid_colours[i], inlen))
+		if (!g_ascii_strncasecmp (inptr, valid_colours[i], inlen))
 			return g_strdup (valid_colours[i]);
 	}
 	
@@ -252,7 +248,7 @@ param_parse_colour (const char *inptr, int inlen)
 }
 
 static char *
-param_parse_font (const char *fontfamily, int inlen)
+param_parse_font (const char *fontfamily, size_t inlen)
 {
 	register const char *inptr = fontfamily;
 	const char *inend = inptr + inlen;
@@ -265,7 +261,7 @@ param_parse_font (const char *fontfamily, int inlen)
 }
 
 static char *
-param_parse_lang (const char *lang, int inlen)
+param_parse_lang (const char *lang, size_t inlen)
 {
 	register const char *inptr = lang;
 	const char *inend = inptr + inlen;
@@ -278,12 +274,12 @@ param_parse_lang (const char *lang, int inlen)
 }
 
 static char *
-param_parse (const char *enriched, const char *inptr, int inlen)
+param_parse (const char *enriched, const char *inptr, size_t inlen)
 {
-	int i;
+	guint i;
 	
 	for (i = 0; i < NUM_ENRICHED_TAGS; i++) {
-		if (!strcasecmp (enriched, enriched_tags[i].enriched))
+		if (!g_ascii_strcasecmp (enriched, enriched_tags[i].enriched))
 			return enriched_tags[i].parse_param (inptr, inlen);
 	}
 	
@@ -424,14 +420,14 @@ enriched_to_html (GMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 				goto need_input;
 			}
 			
-			if (!strncasecmp (tag, "nofill>", 7)) {
+			if (!g_ascii_strncasecmp (tag, "nofill>", 7)) {
 				if ((outptr + 5) < outend) {
 					enriched->nofill++;
 				} else {
 					inptr = tag - 1;
 					goto backup;
 				}
-			} else if (!strncasecmp (tag, "/nofill>", 8)) {
+			} else if (!g_ascii_strncasecmp (tag, "/nofill>", 8)) {
 				if ((outptr + 6) < outend) {
 					enriched->nofill--;
 				} else {
@@ -441,7 +437,7 @@ enriched_to_html (GMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 			} else {
 				const char *html_tag;
 				char *enriched_tag;
-				int len;
+				size_t len;
 				
 				len = inptr - tag;
 				enriched_tag = g_alloca (len + 1);
@@ -464,7 +460,7 @@ enriched_to_html (GMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 							goto need_input;
 						}
 						
-						if (strncasecmp (inptr, "<param>", 7) != 0) {
+						if (g_ascii_strncasecmp (inptr, "<param>", 7) != 0) {
 							/* ignore the enriched command tag... */
 							inptr -= 1;
 							goto loop;
@@ -481,7 +477,7 @@ enriched_to_html (GMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 							goto need_input;
 						}
 						
-						if (strncasecmp (inptr, "</param>", 8) != 0) {
+						if (g_ascii_strncasecmp (inptr, "</param>", 8) != 0) {
 							/* ignore the enriched command tag... */
 							inptr += 7;
 							goto loop;
